require 'rest-client'
require 'json'

require "cubaru/version"
require 'cubaru/error'
require 'cubaru/v1/resource'
require "cubaru/v1/address/resource"
require "cubaru/v1/postcard/resource"

module Cubaru
  class << self
    attr_accessor :api_key,
      :api_version,
      :protocol,
      :api_host

    def configure
      yield self
      true
    end

		def require_options(options, *keys)
			keys.each do |key|
				raise ArgumentError.new(":#{key} is required") unless options.key?(key)
			end
		end

		def submit(method, url, parameters={})
			parameters = {:params => parameters} if method == :get
			JSON(RestClient.send(method, url, parameters))
		rescue => e
			error_message = nil
			raise e unless e.respond_to? :http_body
			begin
				json = JSON(e.http_body)

				if json.has_key? 'errors'
					error_message = json["errors"].first.values.first
				elsif json.has_key? 'message'
					error_message = json["message"]
				else
					error_message = "Unknown error: #{json}"
				end
			rescue => e
				raise e
			end
			raise Cubaru::Error.new(error_message)
		end
	end
end

def Cubaru(options={})
  options[:api_host]     ||= Cubaru.api_host    || "api.cubaru.com"
  options[:protocol]     ||= Cubaru.protocol    || "https"
  options[:api_version]  ||= Cubaru.api_version || "v1"
  options[:api_key]      ||= Cubaru.api_key

  unless options[:api_key]
    raise ArgumentError.new(":api_key is a required argument to initialize Cubaru")
  end

  Cubaru.const_get("#{options[:api_version].capitalize}").const_get("Resource").new(options)
end
